==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/tasks/language/hr.php <==
<?php

﻿;
$l['name']='Zadaci';
$l['description']='Upravljanje zadacima i obvezama.';
$lang['link_type'][12]=$l['task']='Zadatak';
$l['status']='Status';
$l['scheduled_call']='Zakazani poziv u %s';
$l['statuses']['NEEDS-ACTION'] = 'Potrebno djelovati';
$l['statuses']['ACCEPTED'] = 'Prihvaćeno';
$l['statuses']['DECLINED'] = 'Odbijeno';
$l['statuses']['TENTATIVE'] = 'Privremeno';
$l['statuses']['DELEGATED'] = 'Delegirano';
$l['statuses']['COMPLETED'] = 'Završeno';
$l['statuses']['IN-PROCESS'] = 'U procesu';
$l['import_success']='%s zadataka je uvezeno';
$l['call']='Poziv';
$l['dueAtdate']='Dospijeva %s';
$l['list']='Lista zadataka';
$l['tasklistChanged']="* Lista zadataka promjenjena iz '%s' u '%s'";
$l['statusChanged']="* Status promjenjen iz '%s' u '%s'";
$l['multipleSelected']='Više listi zadataka odabrano';
$l['incomplete_delete']='Nemate dopuštenje za brisanje svih odabranih zadataka';﻿;
$l["task"]= 'Zadatak';
$l["noTask"]= 'Nema zadataka za prikazati';
$l["tasks"]= 'Zadaci';
$l["addTask"]= 'Dodaj zadatak...';
$l["tasklist"]= 'Lista zadataka';
$l["tasklists"]= 'Liste zadataka';
$l["showCompletedTasks"]= 'Prikaži dovršene zadatke';
$l["filter"]= 'Filter';
$l["dueDate"]= 'Datum dospjeća';
$l["dueAt"]= 'Dospjeva';
$l["needsAction"]= 'Potrebno djelovati';
$l["accepted"]= 'Prihvaćeno';
$l["declined"]= 'Odbijeno';
$l["tentative"]= 'Privremeno';
$l["delegated"]= 'Delegirano';
$l["completed"]= 'Završeno';
$l["inProcess"]= 'U procesu';
$l["repeatEvery"]= 'Ponavljaj svaki';
$l["atDays"]= 'Na dane';
$l["repeatUntil"]= 'Ponavljaj do';
$l["repeatForever"]= 'ponavljaj zauvijek';
$l["recurrence"]= 'Ponavljanje';
$l["remindMe"]= 'Podsjeti me';
$l["options"]= 'Opcije';
$l["createLink"]= 'Napravi link';
$l["startsAt"]='Počinje';
$l["completedAt"]='Završava';
$l["showInactiveTasks"]='Prikaži neaktivne zadatke';
$l["scheduleCall"]='Zakaži poziv';
$l["call"]='Poziv';
$l["taskDefaults"]='Zadane postavke za zadatke';
$l["daysBeforeStart"]='Dana prije početka';
$l["defaultTasklist"]='Zadana lista zadataka';
$l["visibleTasklists"]='Vidljive liste zadataka';
$l["visible"]='Vidljivo';
$l["selectIcalendarFile"]='Odaberite ikalendar (*.ics) datoteku';
$l["continueTask"]='Nastavite zadatak';
$l["categories"]='Kategorije';
$l["category"]='Kategorija';
$l["selectCategory"]='Odaberite kategoriju';
$l["noTasklistSelected"]='Morate izabrati barem jednu listu zadataka.';
$l["selectAllTasklists"]='Odaberite sve liste zadataka';
$l["globalCategory"]='Globalna kategorija';
$l["showFutureTasks"]='Prikaži buduće zadatke';
$l["incompleteTasks"]='Nedovršeni zadaci';
$l["dueInSevenDays"]='Dospijeva u sedam dana';
$l["overDue"]='Prekoračen rok';
$l["futureTasks"]='Budući zadaci';
$l["all"]='Svi';
$l["active"]='Aktivni';
$l["globalsettings_templatelabel"]='Predložak zadatka';
$l["globalsettings_allchangelabel"]='Promjeni postojeće?';
$l["globalsettings_renameall"]= 'Preimenuj sve?';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/tasks/language/hr.php <==
<?php

$l['name']='Zadaci';
$l['description']='Upravljanje zadacima i obvezama.';
$lang['link_type'][12]=$l['task']='Zadatak';
$l['status']='Status';
$l['scheduled_call']='Zakazani poziv u %s';
$l['statuses']['NEEDS-ACTION'] = 'Potrebno djelovati';
$l['statuses']['ACCEPTED'] = 'Prihvaćeno';
$l['statuses']['DECLINED'] = 'Odbijeno';
$l['statuses']['TENTATIVE'] = 'Privremeno';
$l['statuses']['DELEGATED'] = 'Delegirano';
$l['statuses']['COMPLETED'] = 'Završeno';
$l['statuses']['IN-PROCESS'] = 'U procesu';
$l['import_success']='%s zadataka je uvezeno';
$l['call']='Poziv';
$l['dueAtdate']='Dospijeva %s';
$l['list']='Lista zadataka';
$l['tasklistChanged']="* Lista zadataka promjenjena iz '%s' u '%s'";
$l['statusChanged']="* Status promjenjen iz '%s' u '%s'";
$l['multipleSelected']='Više listi zadataka odabrano';
$l['incomplete_delete']='Nemate dopuštenje za brisanje svih odabranih zadataka';;
$l["task"]= 'Zadatak';
$l["noTask"]= 'Nema zadataka za prikazati';
$l["tasks"]= 'Zadaci';
$l["addTask"]= 'Dodaj zadatak...';
$l["tasklist"]= 'Lista zadataka';
$l["tasklists"]= 'Liste zadataka';
$l["showCompletedTasks"]= 'Prikaži dovršene zadatke';
$l["filter"]= 'Filter';
$l["dueDate"]= 'Datum dospjeća';
$l["dueAt"]= 'Dospjeva';
$l["needsAction"]= 'Potrebno djelovati';
$l["accepted"]= 'Prihvaćeno';
$l["declined"]= 'Odbijeno';
$l["tentative"]= 'Privremeno';
$l["delegated"]= 'Delegirano';
$l["completed"]= 'Završeno';
$l["inProcess"]= 'U procesu';
$l["repeatEvery"]= 'Ponavljaj svaki';
$l["atDays"]= 'Na dane';
$l["repeatUntil"]= 'Ponavljaj do';
$l["repeatForever"]= 'ponavljaj zauvijek';
$l["recurrence"]= 'Ponavljanje';
$l["remindMe"]= 'Podsjeti me';
$l["options"]= 'Opcije';
$l["createLink"]= 'Napravi poveznicu';
$l["startsAt"]='Počinje';
$l["completedAt"]='Završava';
$l["showInactiveTasks"]='Prikaži neaktivne zadatke';
$l["scheduleCall"]='Zakaži poziv';
$l["call"]='Poziv';
$l["taskDefaults"]='Zadane postavke za zadatke';
$l["daysBeforeStart"]='Dana prije početka';
$l["defaultTasklist"]='Zadana lista zadataka';
$l["visibleTasklists"]='Vidljive liste zadataka';
$l["visible"]='Vidljivo';
$l["selectIcalendarFile"]='Odaberite ikalendar (*.ics) datoteku';
$l["continueTask"]='Nastavite zadatak';
$l["categories"]='Kategorije';
$l["category"]='Kategorija';
$l["selectCategory"]='Odaberite kategoriju';
$l["noTasklistSelected"]='Morate izabrati barem jednu listu zadataka.';
$l["selectAllTasklists"]='Odaberite sve liste zadataka';
$l["globalCategory"]='Globalna kategorija';
$l["showFutureTasks"]='Prikaži buduće zadatke';
$l["incompleteTasks"]='Nedovršeni zadaci';
$l["dueInSevenDays"]='Dospijeva u sedam dana';
$l["overDue"]='Prekoračen rok';
$l["futureTasks"]='Budući zadaci';
$l["all"]='Svi';
$l["active"]='Aktivni';
$l["globalsettings_templatelabel"]='Predložak zadatka';
$l["globalsettings_allchangelabel"]='Promjeni postojeće?';
$l["globalsettings_renameall"]= 'Preimenuj sve?';

$l["taskName"]='Naziv';
$l["taskCtime"]='Stvoreno';
$l["taskMtime"]='Izmjenjeno';
$l["taskDue_time"]='Dospjeva';
$l["taskStatus"]='Status';
$l["taskCompletion_time"]='Završeno';
$l["taskProject_name"]='Projekt';
$l['taskPercentage_complete']='Postotak završenosti';
